Change Log for v0.2.x — OppiaMobile 0.4.2 documentation

### Navigation

- index
- next |
- previous |
- OppiaMobile 0.4.2 documentation »
- Change Log »

# Change Log for v0.2.x

## v0.2.15 - 21-Mar-2014

- Fix https://github.com/DigitalCampus/django-oppia/issues/138 - add login/register/download to tracker

## v0.2.14 - 20-Mar-2014

- Fix https://github.com/DigitalCampus/django-oppia/issues/133 - add visualizations page
- Fix https://github.com/DigitalCampus/django-oppia/issues/137 - add lang to tracker model
- Fix https://github.com/DigitalCampus/django-oppia/issues/136 - update visualization to include langs

## v0.2.12/13 - 18-Mar-2014

- Fix https://github.com/DigitalCampus/django-oppia/issues/134 - add country full name
- Fix https://github.com/DigitalCampus/django-oppia/issues/135 - exclude staff hits

## v0.2.10/11 - 17-Mar-2014

- Fix for urllib/urllib2

## v0.2.8/9 - 17-Mar-2014

- Fix https://github.com/DigitalCampus/django-oppia/issues/127 - add IP location cache table
- Fix https://github.com/DigitalCampus/django-oppia/issues/125 - add optional data to media model
- Fix https://github.com/DigitalCampus/django-oppia/issues/113 - not removing old course versions
- added util to update the carto db map
- added util to tidy up course upload dir

## v0.2.7 - 14-Mar-2014

- Fix https://github.com/DigitalCampus/django-oppia/issues/121 - error in Excel export
- Add https://github.com/DigitalCampus/django-oppia/issues/123 - updates to tag model

## v0.2.6 - 8-Mar-2014

- Fix https://github.com/DigitalCampus/django-oppia/issues/90 - split points/badges
- Fix issue with badges API
- Limit number of records returned with points API

## v0.2.5 - 4-Mar-2014

- New required library - django-taglib
- Added ip2location.py utility script
- Fix https://github.com/DigitalCampus/django-oppia/issues/83 - adding profile gravatar
- Fix https://github.com/DigitalCampus/django-oppia/issues/105 - option to export activity logs to csv/xls

## v0.2.1

- Fix: https://github.com/DigitalCampus/django-oppia/issues/100 - ensure full list of tags/courses returned
- Fix: https://github.com/DigitalCampus/django-oppia/issues/111 - don’t assign badges for creating quizzes
- Fix: https://github.com/DigitalCampus/django-oppia/issues/114 - use UUID for trackers

## v0.2.0

- Fix: https://github.com/DigitalCampus/django-oppia/issues/110 - quizprops post api
- Fix: https://github.com/DigitalCampus/django-oppia/issues/106 - cache activity/seciton title in tracker table

### Navigation

- index
- next |
- previous |
- OppiaMobile 0.4.2 documentation »
- Change Log »